#[non_exhaustive]pub enum Error {
Native(i32),
Memory(Cow<'static, str>),
Parse(String),
Path(PathBuf),
Bug(String),
Config(String),
Io(Error),
}Expand description
An error that can occur
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Native(i32)
An error that occurred interfacing with native code through FFI.
Memory(Cow<'static, str>)
An error that occurred while accessing or allocating memory
Parse(String)
An error that occurred while parsing a data source
Path(PathBuf)
An error that occurred while working with a file path.
Bug(String)
Generally, these errors correspond to bugs in this library.
Config(String)
An error occurred while reading/writing a configuration
Io(Error)
An unexpected I/O error occurred.