meshopt_encodeVertexBufferLevel

Function meshopt_encodeVertexBufferLevel 

pub unsafe extern "C" fn meshopt_encodeVertexBufferLevel(
    buffer: *mut c_uchar,
    buffer_size: usize,
    vertices: *const c_void,
    vertex_count: usize,
    vertex_size: usize,
    level: c_int,
    version: c_int,
) -> usize
Vertex buffer encoder Encodes vertex data just like meshopt_encodeVertexBuffer, but allows to override compression level. For compression level to take effect, the vertex encoding version must be set to 1. The default compression level implied by meshopt_encodeVertexBuffer is 2.

level should be in the range [0, 3] with 0 being the fastest and 3 being the slowest and producing the best compression ratio. version should be -1 to use the default version (specified via meshopt_encodeVertexVersion), or 0/1 to override the version; per above, level won’t take effect if version is 0.