pub unsafe extern "C" fn meshopt_quantizeFloat(
v: f32,
N: c_int,
) -> f32Expand description
Quantize a float into a floating point value with a limited number of significant mantissa bits, preserving the IEEE-754 fp32 binary representation Generates +-inf for overflow, preserves NaN, flushes denormals to zero, rounds to nearest Assumes N is in a valid mantissa precision range, which is 1..23